# stanfordpy-graphics

The Stanford Graphics library

## Installation

```bash
pip install stanfordpy-graphics
```

## Development

To run the local version of the library, run:

```bash
pip install -e .
```

Don't forget to bump the version in `pyproject.toml` before releasing!
